SystemOrganization addCategory: #ConfigurationOfParasol!

Object subclass: #ConfigurationOfParasol
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfParasol'!

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfParasol class methodsFor: 'metacello tool support' stamp: 'KrisGybels 6/22/2012 17:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfParasol class methodsFor: 'loading' stamp: 'KrisGybels 7/4/2012 16:44'!
load

	"self load"

	<apiDocumentation>
	^(self project version: '1.0-baseline') load! !

!ConfigurationOfParasol class methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^self new project! !

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'AndyKellens 7/22/2013 07:38'!
baseline10: spec

	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://ss3.gemstone.com/ss/Parasol';
			yourself.
		spec 
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					version: #stable;
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'Parasol-Core';
			package: 'Parasol-Tests' with: [ spec requires: #('Parasol-Core' 'Seaside30') ];
			package: 'Parasol-Convenience' with: [ spec requires: #('Parasol-Core') ];
			yourself.
		spec
			group: 'default' with: #('Parasol-Core' 'Parasol-Convenience');
			group: 'dev' with: #('Parasol-Tests' 'default');
			yourself.
	].

	spec for: #squeak do: [
		spec
			project: 'Seaside30' with: [	spec loads: #('Core' 'WebClient-Seaside')];
			yourself.
		spec 
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					version: #stable;
					file: 'ConfigurationOfWebClient';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'Parasol-Squeak' with: [ spec requires: #('Parasol-Core' 'Seaside30' 'WebClient') ];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Squeak');
			yourself.
	].

	spec for: #pharo do: [
		"Sets the Zinc prerequisite for Pharo"
			spec 
				project: 'ZincHTTP'
				with: 
					[ spec
						className: 'ConfigurationOfZincHTTPComponents';
						versionString: #stable;
						file: 'ConfigurationOfZincHTTPComponents';
						loads: 'Core';
						repository: 'http://www.squeaksource.com/ZincHTTPComponents'].
		spec 
			package: 'Parasol-Core' 
			with: [ spec requires: #('ZincHTTP') ].
	].

	spec for: #'pharo1.x'  do: [
		spec 
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					versionString: '3.0.7.1';
					file: 'ConfigurationOfSeaside30';
					loads: #('Core' 'Seaside-Adaptors-Comanche');
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Pharo');
			yourself.
	].

	spec for: #'pharo2.x' do: [
		spec
			project: 'Seaside30' overrides: [
				spec
					className: 'ConfigurationOfSeaside30';
					versionString: '3.0.8';
					file: 'ConfigurationOfSeaside30';
					loads: #('Core' 'Zinc-Seaside');
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
			
			spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Pharo');
			yourself.
	].
	
	spec for: #gemstone do: [
		spec baseline: 'ZincHTTP'.
		spec 
			project: 'Seaside30' with: [ spec loads: #('Core') ];
			yourself.
		spec
			package: 'Parasol-Core' with: [ spec requires: #('ZincHTTP') ];
			yourself.
	].
	
	spec for: #'gs2.4.x' do: [
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone2.4/repository'];
			yourself.
	].
		
	spec for: #'gs3.1.x' do:[
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone3.1/repository'];
			yourself.
	].
! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'JohanBrichau 4/14/2013 13:00'!
bleedingEdge: spec

	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '1.0-baseline'.
! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'KrisGybels 8/14/2013 08:50'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.11'.
! !

!ConfigurationOfParasol methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'JohanBrichau 4/14/2013 16:28'!
stable: spec

	<symbolicVersion: #'stable'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 5/31/2013 20:50'!
version010: spec
	<version: '0.10' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '5/31/2013 20:50'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-JohanBrichau.23';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: ''.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 8/14/2013 14:19'!
version011: spec
	<version: '0.11' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.26';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: ''.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'topa 4/18/2013 08:21'!
version09: spec
	<version: '0.9' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '4/14/2013 13:11'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-topa.22';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.4'. ].

	spec for: #'squeak' do: [
		spec project: 'Seaside30' with: #stable.
		spec project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' .
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !
